/*****************************************************************************

	Felix IRC client
	UserAction Add-ons sample code

	This is one of the 3 API to create add-ons in Felix.
	This type of add-ons just receive the nick of a user.
	They're expected to do some action on him.
	
	The add-ons can be automatically called by Felix on defined event.
	Just configure the event manager in the 'IRC prefs' of the main window

	Other information are sent to the add-ons :
		* the channel from which the add-ons is called,
		* BLooper to send RAW IRC message.
		* His IP address if you want to do an action without using the IRC server.
		
	'channel' and 'ip' string accepts NULL as a valid value.
	'nick' and 'loop' have always no NULL values.
	
	If you need the ip adress and/or the channel name, and the value(s) received is NULL,
	just put a BAlert on screen saying you can't do the action
	("Unknow IP address" for example)

	IMPORTANT :
	===========
	If you want to do a big action please spawn a thread in order to avoid
	blocking the calling thread.
	
	Message Protocol :
	------------------
	name		type			value
	"what"		B_INT32_TYPE	'Imsg'
	"IrcRaw"	B_STRING_TYPE	Your irc string

revision : 10/02/97

Modification :
	- in order to have prefs for each addon, the addon must create a BView.
	  the view must be 233x228 and support its own BMessages.
	  The view won't be resized.
	  The addon must manage itself to save the data in a file.
	  the file path must be "[B_USER_SETTINGS_DIRECTORY]/Felix/"
	- New init function. It return the BView. This function is the same for all
	  AddOns (global, action and dcc).
	  The BView can be NULL. In that case, a default view will be created.
	- In the former version, each server has its own image of the add on. Now, there is
	  only one image for all the servers. They just call a function to have their own looper.
	  Thus, all the loopers can share datas (thru global vars).

	For more information : ducrohet@club-internet.fr


*****************************************************************************/



#pragma export on
extern "C" BView * AddOnInit(void);
extern "C" void Action(const char *nick, const char *ip,const char *channel, BLooper *loop);
#pragma export reset


BView * AddOnInit(void) {
	BView *view = new BView (BRect(0,0,233,228),"view", B_FOLLOW_NONE,B_WILL_DRAW);
	view->SetViewColor(210,210,210);
	BStringView *titre = new BStringView(BRect(20,10,230,30),"text","WebConnect");
	view->AddChild(titre);
	titre = new BStringView(BRect(20,30,230,45),"text"," © Copyright 1996-1997 Xavier Ducrohet");
	view->AddChild(titre);
	titre = new BStringView(BRect(20,45,230,60),"text","All Rights Reserved");
	view->AddChild(titre);
	titre = new BStringView(BRect(20,70,230,85),"text","Http connection to the selected user,");
	view->AddChild(titre);
	titre = new BStringView(BRect(20,85,230,100),"text","using the defined text/html handler");
	view->AddChild(titre);
	return view;
}

void Action(const char */*nick*/, const char *ip,const char */*channel*/, BLooper */*loop*/) {

	if (!ip) {
		(new BAlert("","Unknown IP adress for that user","Sorry"))->Go();
	}
	else {
		char *url = new char[512];
		sprintf(url,"http://%s",ip);
		status_t	result;
		result = be_roster->Launch("text/html", 1, &url);
		if ((result != B_NO_ERROR) && (result != B_ALREADY_RUNNING)) {
			(new BAlert("", "There is no installed handler for 'text/html'.",
				"Sorry"))->Go();
		}
		delete[] url;
	}
}

